@@ -1,14 +1,15 @@
 package File::Prepend::Undoable;
 
+our $DATE = '2015-08-17'; # DATE
+our $VERSION = '0.03'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::Any::IfLOG '$log';
 
 use File::Trash::Undoable;
 
-our $VERSION = '0.02'; # VERSION
-
 our %SPEC;
 
 $SPEC{prepend} = {
@@ -135,15 +136,20 @@ File::Prepend::Undoable - Prepend string to a file, with undo support
 
 =head1 VERSION
 
-This document describes version 0.02 of File::Prepend::Undoable (from Perl distribution File-Prepend-Undoable), released on 2014-05-17.
+This document describes version 0.03 of File::Prepend::Undoable (from Perl distribution File-Prepend-Undoable), released on 2015-08-17.
+
+=head1 SEE ALSO
+
+L<Rinci::Transaction>
 
 =head1 FUNCTIONS
 
 
 =head2 prepend(%args) -> [status, msg, result, meta]
 
-Prepend string to a file, with undo support.
+{en_US Prepend string to a file, with undo support}.
 
+{en_US 
 On do, will trash file, copy it to original location (with the same permission
 and ownership as the original) and prepend the string to the beginning of file.
 On undo will trash the new file and untrash the original.
@@ -152,32 +158,16 @@ Some notes:
 
 =over
 
-=item *
+=item * Chown will not be done if we are not running as root.
 
-Chown will not be done if we are not running as root.
-
-
-
-=item *
-
-Symlink is currently not permitted.
-
-
-
-=item *
-
-Since transaction requires the function to be idempotent, in the C<check_state>
-  phase the function will check if the string has been prepended. It will refuse
-  to prepend the same string twice.
-
-
-
-=item *
-
-Take care not to use string that are too large, as the string, being a
-  function parameter, is entered into the transaction table.
+=item * Symlink is currently not permitted.
 
+=item * Since transaction requires the function to be idempotent, in the C<check_state>
+phase the function will check if the string has been prepended. It will refuse
+to prepend the same string twice.
 
+=item * Take care not to use string that are too large, as the string, being a
+function parameter, is entered into the transaction table.
 
 =back
 
@@ -188,6 +178,7 @@ file.
 
 Unfixable state: file does not exist or path is not a regular file (directory
 and symlink included).
+}
 
 This function is idempotent (repeated invocations with same arguments has the same effect as single invocation). This function supports transactions.
 
@@ -198,11 +189,11 @@ Arguments ('*' denotes required arguments):
 
 =item * B<path>* => I<str>
 
-The file to prepend.
+{en_US The file to prepend}.
 
 =item * B<string>* => I<any>
 
-The string to prepend to file.
+{en_US The string to prepend to file}.
 
 =back
 
@@ -232,8 +223,6 @@ For more information on transaction, see L<Rinci::Transaction>.
 
 =back
 
-Return value:
-
 Returns an enveloped result (an array).
 
 First element (status) is an integer containing HTTP status code
@@ -243,9 +232,7 @@ First element (status) is an integer containing HTTP status code
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
-=head1 SEE ALSO
-
-L<Rinci::Transaction>
+Return value:  (any)
 
 =head1 HOMEPAGE
 
@@ -265,11 +252,11 @@ feature.
 
 =head1 AUTHOR
 
-Steven Haryanto <stevenharyanto@gmail.com>
+perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Steven Haryanto.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
